@@ -34,6 +34,7 @@ import dbus
 import logging
 import sys
 import shlex
+import pipes
 from gobject import TYPE_PYOBJECT as gPyobject
 from twisted.internet import reactor
 from twisted.python import log
@@ -48,7 +49,6 @@ from client_information import ClientInformation
 from remote_assistance import RemoteAssistance
 from epoptes.daemon import uiconnection
 from epoptes.core.lib_users import *
-from epoptes.common import commands
 from epoptes.common import ltsconf
 from epoptes.common import config
 from epoptes.common.constants import *
@@ -59,15 +59,16 @@ from epoptes.core import structs
 class EpoptesGui(object):
     
     def __init__(self):
-        self.c = commands.commands()
         self.shownCompatibilityWarning = False 
         self.vncserver = None
         self.vncviewer = None
         self.scrWidth = 100
         self.scrHeight = 75
+        self.currentScreenshots = dict()
         self.current_macs = subprocess.Popen(['sh', '-c', 
-        """ip -oneline -family inet link show | sed -n '/.*ether[[:space:]]*\\([[:xdigit:]:]*\).*/{s//\\1/;y/abcdef-/ABCDEF:/;p;}'"""], 
-                                             stdout=subprocess.PIPE).stdout.read().split()
+            """ip -oneline -family inet link show | sed -n '/.*ether[[:space:]]*\\([[:xdigit:]:]*\).*/{s//\\1/;y/abcdef-/ABCDEF:/;p;}'
+            echo $LTSP_CLIENT_MAC"""],
+            stdout=subprocess.PIPE).communicate()[0].split()
         if os.getuid() != 0:
             if 'thumbnails_width' in config.user:
                 self.scrWidth = config.user['thumbnails_width']
@@ -123,6 +124,17 @@ class EpoptesGui(object):
             self.gstore.append([grp.name, grp, True])
         
         self.fillIconView(self.getSelectedGroup()[1])
+        if config.settings.has_option('GUI', 'selected_group'):
+            path = config.settings.getint('GUI', 'selected_group')
+            self.gtree.get_selection().select_path(path)
+        if config.settings.has_option('GUI', 'label'):
+            try:
+                self.get(config.settings.get('GUI', 'label')).set_active(True)
+            except:
+                pass
+        self.showRealNames = False
+        if config.settings.has_option('GUI', 'showRealNames'):
+            self.get('mcShowRealNames').set_active(config.settings.getboolean('GUI', 'showRealNames'))
 
     #################################################################
     #                       Callback functions                      #
@@ -148,17 +160,40 @@ class EpoptesGui(object):
 
         Close main window
         """
+        sel_group = self.gstore.get_path(self.getSelectedGroup()[0])[0]
         self.gstore.remove(self.gstore.get_iter(self.default_group.ref.get_path()))
         config.save_groups(os.path.expanduser('~/.config/epoptes/groups.json'), self.gstore)
+        settings = config.settings
+        if not settings.has_section('GUI'):
+            settings.add_section('GUI')        
+        if self.get('miClientsViewHostUser').get_active():
+            label = 0
+        elif self.get('miClientsViewHost').get_active():
+            label = 1
+        elif self.get('miClientsViewUserHost').get_active():
+            label = 2
+        elif self.get('miClientsViewUser').get_active():
+            label = 3
+        
+        settings.set('GUI', 'selected_group', sel_group)
+        settings.set('GUI', 'showRealNames', self.showRealNames)
+        f = open(os.path.expanduser('~/.config/epoptes/settings'), 'wb')
+        settings.write(f)
+        f.close()
+        
         if not self.vncserver is None:
             self.vncserver.kill()
         if not self.vncviewer is None:
             self.vncviewer.kill()
+        # Work around http://twistedmatrix.com/trac/ticket/5503
+        reactor.crash()
         reactor.stop()
             
     def toggleRealNames(self, widget=None):
         """Show/hide the real names of the users instead of the usernames"""
-        pass # Implement me
+        self.showRealNames = widget.get_active()
+        for row in self.cstore:            
+            self.setLabel(row)
 
     def wake_on_lan(self, widget):
         """Boot the selected computers with WOL"""
@@ -170,19 +205,20 @@ class EpoptesGui(object):
 
     def poweroff(self, widget):
         """Shut down the selected clients."""
-        self.execOnSelectedClients(self.c.POWEROFF, root="auto",
-            warn=self.c.POWEROFF_WARN)
+        self.execOnSelectedClients("shutdown", root="auto",
+            warn=_('Are you sure you want to shutdown all the computers?'))
 
     def reboot(self, widget):
         """Reboot the selected clients."""
         # FIXME: (Not) waiting on purpose to cause some delay to avoid 
         # any power strain.
-        self.execOnSelectedClients(self.c.REBOOT, root="auto",
-            warn=self.c.REBOOT_WARN)
+        self.execOnSelectedClients("reboot", root="auto",
+            warn=_('Are you sure you want to reboot all the computers?'))
 
     def logout(self, widget):
         """Log off the users of the selected clients."""
-        self.execOnSelectedClients(self.c.LOGOUT, warn=self.c.LOGOUT_WARN)
+        self.execOnSelectedClients("logout",
+            warn=_('Are you sure you want to log off all the users?'))
 
 
     def reverseConnection(self, widget, path, view_column, cmd):
@@ -191,17 +227,15 @@ class EpoptesGui(object):
             self.vncviewer = subprocess.Popen(['xvnc4viewer', '-listen'])
 
         # And, tell the clients to connect to the server
-        self.execOnSelectedClients(self.c.EXEC + cmd)
+        self.execOnSelectedClients(cmd)
 
 
     def assistUser(self, widget, path=None, view_column=None):
-        self.reverseConnection(widget, path, view_column,
-            'x11vnc -noshm -24to32 -connect_or_exit $SERVER')
+        self.reverseConnection(widget, path, view_column, 'get_assisted')
 
 
     def monitorUser(self, widget, path=None, view_column=None):
-        self.reverseConnection(widget, path, view_column,
-            'x11vnc -noshm -24to32 -viewonly -connect_or_exit $SERVER')
+        self.reverseConnection(widget, path, view_column, 'get_monitored')
 
 
     def findUnusedPort(self, base=None):
@@ -227,7 +261,7 @@ class EpoptesGui(object):
             return None
 
 
-    def broadcastScreen(self, widget):
+    def _broadcastScreen(self, fullscreen=''):
         if self.vncserver is None:
             self.vncport = self.findUnusedPort()
             # TODO: use a password instead of -allow
@@ -235,29 +269,18 @@ class EpoptesGui(object):
                 '-quiet', '-viewonly', '-shared', '-forever', '-nolookup',
                 '-24to32', '-rfbport', str(self.vncport), '-allow',
                 '127.,192.168.,10.,169.254.' ])
-        self.execOnSelectedClients("""killall gnome-screensaver 2>/dev/null""")
-        # TODO: don't use sleep on the direct client shell, use execute script instead
-        # pgrep -x only checks the first 15 characters found in /proc/pid/stat.
-        # Check the length with e.g.: x="lxdm-greeter-gtk"; echo ${x:0:15}
-        # The following greeters spawn dbus-daemon, so there's no need for them
-        # to be in the greeters list:
-        # gdm-simple-greeter, unity-greeter
-        # Unfortunately, dbus-daemon doesn't contain DBUS_SESSION_BUS_ADDRESS.
-        self.execOnSelectedClients("""
-test -n "$EPOPTES_VNCVIEWER_PID" && kill $EPOPTES_VNCVIEWER_PID
-export $(./get-display)
-xset dpms force on
-sleep 0.$((`hexdump -e '"%%d"' -n 2 /dev/urandom` %% 50 + 50))
-EPOPTES_VNCVIEWER_PID=$(./execute xvnc4viewer -Shared -ViewOnly -FullScreen \
--UseLocalCursor=0 -MenuKey F13 $SERVER:%d)""" % self.vncport, root=True)
-
+        self.execOnSelectedClients('stop_screensaver')
+        self.execOnSelectedClients('receive_broadcast %d %s' % (self.vncport,
+            fullscreen), root=True)
+    
+    def broadcastScreen(self, widget):
+        self._broadcastScreen('true')
+        
+    def broadcastScreenWindowed(self, widget):
+        self._broadcastScreen('')
 
     def stopTransmissions(self, widget):
-        # The vnc clients should automatically exit when the server is killed.
-        # Unfortunately, that isn't always true, so try to kill them anyway.
-        self.execOnClients("""
-test -n "$EPOPTES_VNCVIEWER_PID" && kill $EPOPTES_VNCVIEWER_PID
-unset EPOPTES_VNCVIEWER_PID""", self.cstore, None, True)
+        self.execOnClients('stop_transmissions', self.cstore, None, True)
         if not self.vncserver is None:
             self.vncserver.kill()
             self.vncserver = None
@@ -267,22 +290,40 @@ unset EPOPTES_VNCVIEWER_PID""", self.cstore, None, True)
     def execDialog(self, widget):
         cmd = startExecuteCmdDlg()
         # If Cancel or Close were clicked
-        if cmd == 0 or cmd == -4:
+        if cmd == '':
             return
         as_root = False
         if cmd[:5] == 'sudo ':
             as_root = True
             cmd = cmd[4:]
-        self.execOnSelectedClients(self.c.EXEC + cmd, root=as_root)
+        self.execOnSelectedClients('execute ' + cmd, root=as_root)
 
-    ## FIXME FIXME: Don't use zenity...
+    ## FIXME FIXME: Don't use zenity, use the message command instead...
     def sendMessageDialog(self, widget):
         cmd = startSendMessageDlg()
         if cmd != "": # Command is 'valid', execute on selected clients 
-            as_root = False
-            self.execOnSelectedClients(self.c.EXEC + cmd, root=as_root)
+            self.execOnSelectedClients('execute ' + cmd)
     
     ## FIXME / FIXUS: Should we allow it?
+    def openTerminal(self, as_root):
+        clients = self.getSelectedClients()
+        
+        # If there is no client selected, send the command to all
+        if len(clients) == 0:
+            clients = self.cstore
+
+        for client in clients:
+            inst = client[C_INSTANCE]
+            if inst.type == 'offline':
+                continue
+
+            port = self.findUnusedPort()
+
+            subprocess.Popen(['xterm', '-e', 'socat',
+                'tcp-listen:%d,keepalive=1' % port, 'stdio,raw,echo=0'])
+            self.execOnClients('remote_term %d' % port, [client],
+                root=as_root)
+
     def openUserTerminal(self, widget):
         self.openTerminal(False)
 
@@ -290,39 +331,33 @@ unset EPOPTES_VNCVIEWER_PID""", self.cstore, None, True)
         self.openTerminal(True)
 
     def remoteRootTerminal(self, widget):
-        self.execOnSelectedClients("""
-export $(./get-display)
-./execute xterm -e bash -l""", root=True)
+        self.execOnSelectedClients('root_term', root=True)
     ## END_FIXUS
 
-    # FIXME : Change the way lock screen works, don't kill and relock...
     def lockScreen(self, widget):
         """
-        Lock screen for all clients selected
+        Lock screen for all the selected clients, displaying a message
         """
-        self.execOnSelectedClients('test -n "$EPOPTES_LOCK_SCREEN_PID" && kill ' + \
-            '"$EPOPTES_LOCK_SCREEN_PID"; EPOPTES_LOCK_SCREEN_PID=$(./execute ' + \
-            './lock-screen)')
+        msg = _("The screen is locked by a system administrator.")
+        self.execOnSelectedClients('lock_screen 0 %s' % pipes.quote(msg))
 
     def unlockScreen(self, widget):
         """
         Unlock screen for all clients selected
         """
-        self.execOnSelectedClients('''test -n "$EPOPTES_LOCK_SCREEN_PID" && ''' + \
-            '''kill "$EPOPTES_LOCK_SCREEN_PID"; unset EPOPTES_LOCK_SCREEN_PID''')
+        self.execOnSelectedClients('unlock_screen')
 
-    # FIXME: Find something better
     def soundOff(self, widget):
         """
         Disable sound usage for clients selected
         """
-        self.execOnSelectedClients(self.c.EXEC_AMIXER + 'mute', root=True)
+        self.execOnSelectedClients('mute 0', root=True)
 
     def soundOn(self, widget):
         """
         Enable sound usage for clients selected
         """
-        self.execOnSelectedClients(self.c.EXEC_AMIXER + 'unmute', root=True)
+        self.execOnSelectedClients('unmute', root=True)
     
     def on_remove_from_group_clicked(self, widget):
         clients = self.getSelectedClients()
@@ -381,15 +416,19 @@ export $(./get-display)
         
     def on_cViewHU_toggled(self, mitem):
         self.set_cView(1, 0)
+        config.settings.set('GUI', 'label', 'miClientsViewHostUser')
     
     def on_cViewUH_toggled(self, mitem):
         self.set_cView(0, 1)
+        config.settings.set('GUI', 'label', 'miClientsViewUserHost')
     
     def on_cViewH_toggled(self, mitem):
         self.set_cView(-1, 0)
+        config.settings.set('GUI', 'label', 'miClientsViewHost')
     
     def on_cViewU_toggled(self, mitem):
         self.set_cView(0, -1)
+        config.settings.set('GUI', 'label', 'miClientsViewUser')
     
     def set_cView(self, user_pos= -1, name_pos=0):
         # Save the order so all new clients get the selected format
@@ -404,11 +443,9 @@ export $(./get-display)
     # AMP callbacks
     def amp_clientConnected(self, handle):
         print "New connection from", handle
-        self.daemon.command(handle, u"""
-            VERSION=$(dpkg-query -W -f '${Version}' epoptes-client 2>/dev/null)
-            VERSION=${VERSION:-0.1}
-            echo "$USER\n$HOSTNAME\n$IP\n$MAC\n$TYPE\n$UID\n$VERSION\n$$"
-            """).addCallback(lambda r: self.addClient(handle, r))
+        d = self.daemon.command(handle, u'info')
+        d.addCallback(lambda r: self.addClient(handle, r))
+        d.addErrback(lambda err: self.printErrors("when connecting client %s: %s" %(handle, err)))
 
     def amp_clientDisconnected(self, handle):
         print "Disconnect from", handle
@@ -416,7 +453,7 @@ export $(./get-display)
         def determine_offline(client):
             if client.hsystem == '' and client.users == {}:
                 client.set_offline()
-        
+        client = None
         for client in structs.clients:
             if client.hsystem == handle:
                 if self.getSelectedGroup()[1].has_client(client) or self.isDefaultGroupSelected():
@@ -427,21 +464,25 @@ export $(./get-display)
             
             elif handle in client.users:
                 if self.getSelectedGroup()[1].has_client(client) or self.isDefaultGroupSelected():
-                    logoutNotify(client.users[handle], client.get_name())
+                    logoutNotify(client.users[handle]['uname'], client.get_name())
                 del client.users[handle]
                 determine_offline(client)
                 break
-        self.fillIconView(self.getSelectedGroup()[1])
+            else:
+                client = None
+
+        if not client is None:
+            for row in self.cstore:
+                if row[C_INSTANCE] is client: 
+                    self.fillIconView(self.getSelectedGroup()[1])
+                    break
     
     def amp_gotClients(self, handles):
         print "Got clients:", ', '.join(handles) or 'None'
         for handle in handles:
-            d = self.daemon.command(handle, u"""
-                VERSION=$(dpkg-query -W -f '${Version}' epoptes-client 2>/dev/null)
-                VERSION=${VERSION:-0.1}
-                echo "$USER\n$HOSTNAME\n$IP\n$MAC\n$TYPE\n$UID\n$VERSION\n$$"
-                """)
+            d = self.daemon.command(handle, u'info')
             d.addCallback(lambda r, h=handle: self.addClient(h, r, True))
+            d.addErrback(lambda err: self.printErrors("when enumerating client %s: %s" %(handle, err)))
     
     def on_button_close_clicked(self, widget):
         self.get('warningDialog').hide()
@@ -463,10 +504,14 @@ export $(./get-display)
         """Properly add a Client class instance to the clients iconview."""
         # If there are one or more users on client, add a new iconview entry
         # for each one of them.
+        
+        label = 'uname'
+        if self.showRealNames:
+                label = 'rname'
         if client.users:
             for hsession, user in client.users.iteritems():
-                self.cstore.append([self.calculateLabel(client, user), self.imagetypes[client.type], client, hsession])
-                self.getScreenshots(hsession, self.getSelectedGroup()[1])
+                self.cstore.append([self.calculateLabel(client, user[label]), self.imagetypes[client.type], client, hsession])
+                self.askScreenshot(hsession, True)
         else:
             self.cstore.append([self.calculateLabel(client), self.imagetypes[client.type], client, ''])
     
@@ -496,8 +541,18 @@ export $(./get-display)
         
     def addClient(self, handle, r, already=False):
         # already is True if the client was started before epoptes
-        user, host, ip, mac, type, uid, version, pid = r.strip().split()
         print "---\n**addClient's been called for", handle
+        try:
+            info = {}
+            for line in r.strip().split('\n'):
+                key, value = line.split('=', 1)
+                info[key.strip()] = value.strip()
+            user, host, ip, mac, type, uid, version, name = \
+             info['user'], info['hostname'], info['ip'], \
+             info['mac'], info['type'], info['uid'], info['version'], info['name']
+        except:
+            print "Can't extract client information, won't add this client"
+            return
         
         # Check if the incoming client is the same with the computer in which
         # epoptes is running, so we don't add it to the list.
@@ -523,7 +578,7 @@ which is incompatible with the current epoptes version.\
                 dlg.show()
             self.daemon.command(handle, u"exit")
             return False
-        
+        sel_group = self.getSelectedGroup()[1]
         client = None
         for inst in structs.clients:
             # Find if the new handle is a known client
@@ -544,16 +599,20 @@ which is incompatible with the current epoptes version.\
         else:
             # This is a user epoptes-client
             print '* I am a user client, will add', user, 'in my list'
-            client.add_user(user, handle)
-            if not already and (self.getSelectedGroup()[1].has_client(client) or self.isDefaultGroupSelected()):
+            client.add_user(user, name, handle)
+            if not already and (sel_group.has_client(client) or self.isDefaultGroupSelected()):
                 loginNotify(user, host)
         
-        self.fillIconView(self.getSelectedGroup()[1])
+        if sel_group.has_client(client) or self.isDefaultGroupSelected():
+            self.fillIconView(sel_group)
     
     def setLabel(self, row):
         inst = row[C_INSTANCE]
         if row[C_SESSION_HANDLE]:            
-            user = row[C_INSTANCE].users[row[C_SESSION_HANDLE]]
+            label = 'uname'
+            if self.showRealNames:
+                label = 'rname'
+            user = row[C_INSTANCE].users[row[C_SESSION_HANDLE]][label]
         else:
             user = ''
         row[C_LABEL] = self.calculateLabel(inst, user)
@@ -578,45 +637,75 @@ which is incompatible with the current epoptes version.\
                     label += " (%s)" % username
             return label
     
+    def getShowRealNames(self):
+        return self.get('')
+    
     def getAllScreenshots(self):
         # TODO: Ask for screenshots for every client (Look diff at Rev:326)
         pass
 
-    def getScreenshots(self, handle, group):
+    def screenshotTimeout(self, handle):
+        print "Screenshot for client %s timed out. Requesting a new one..." % handle
+        self.askScreenshot(handle)
+        return False
+        
+    def askScreenshot(self, handle, firstTime=False):
+        # Should always return False to prevent glib from calling us again
+        if firstTime:
+            if not handle in self.currentScreenshots:
+                # Mark that we started asking for screenshots, but didn't yet get one
+                self.currentScreenshots[handle] = None
+            else:
+                # We're already asking the client for screenshots, reuse the existing one
+                if not self.currentScreenshots[handle] is None:
+                    for i in self.cstore:
+                        if handle == i[C_SESSION_HANDLE]:
+                            self.cstore[i.path][C_PIXBUF] = self.currentScreenshots[handle]
+                            break
+                return False
         # TODO: Implement this using gtk.TreeRowReferences instead
         # of searching the whole model (Need to modify execOnClients)
-        if not group is self.getSelectedGroup()[1]:
-            return False
         for client in self.cstore:
             if handle == client[C_SESSION_HANDLE]:
-                self.execOnClients(self.c.SCREENSHOT
+                timeoutID = gobject.timeout_add(10000, lambda h=handle: self.screenshotTimeout(h))
+                self.execOnClients('screenshot %d %d'
                     % (self.scrWidth, self.scrHeight), handles=[handle],
-                        reply=self.updateScreenshots)
+                    reply=self.gotScreenshot, params=[timeoutID])
                 return False
+        # That handle is no longer in the cstore, remove it
+        try: del self.currentScreenshots[handle]
+        except: pass
+        return False
 
 
-    def updateScreenshots(self, handle, reply):
-        if not reply:
+    def gotScreenshot(self, handle, reply, timeoutID):
+        # Cancel the timeout event. If it already happened, exit.
+        if not gobject.source_remove(timeoutID):
             return
-        try:
-            rowstride, size, pixels = reply.strip().split('\n', 2)
-        except:
-            return
-        rowstride = int(rowstride)
-        width, height = size.split('x')
         for i in self.cstore:
             if handle == i[C_SESSION_HANDLE]:
-                pxb = gtk.gdk.pixbuf_new_from_data(pixels,
-                    gtk.gdk.COLORSPACE_RGB, False, 8, int(width), int(height),
-                    rowstride)
-                self.cstore[i.path][C_PIXBUF] = pxb
                 # We want to ask for thumbnails every 5 sec after the last one.
                 # So if the client is too stressed and needs 7 secs to
                 # send a thumbnail, we'll ask for one every 12 secs.
-                # TODO: check if there are cases where we want to continue
-                # asking for screenshots even if we got an empty/broken one.
-                gobject.timeout_add(5000, self.getScreenshots, handle, self.getSelectedGroup()[1])
-                break
+                gobject.timeout_add(5000, self.askScreenshot, handle)
+#                print "I got a screenshot from %s." % handle
+                if not reply:
+                    return
+                try:
+                    rowstride, size, pixels = reply.split('\n', 2)
+                except:
+                    return
+                rowstride = int(rowstride)
+                width, height = size.split('x')
+                pxb = gtk.gdk.pixbuf_new_from_data(pixels,
+                    gtk.gdk.COLORSPACE_RGB, False, 8, int(width), int(height),
+                    rowstride)
+                self.currentScreenshots[handle] = pxb
+                self.cstore[i.path][C_PIXBUF] = pxb
+                return
+        # That handle is no longer in the cstore, remove it
+        try: del self.currentScreenshots[handle]
+        except: pass
     
     def getSelectedClients(self):
         selected = self.cview.get_selected_items()
@@ -704,7 +793,7 @@ which is incompatible with the current epoptes version.\
         self.get('miClientProperties').set_sensitive(sensitive)
         self.get('tb_client_properties').set_sensitive(sensitive)
         
-        if len(selected) >= 1:
+        if len(selected) >= 1 and not self.isDefaultGroupSelected():
             self.get('miRemoveFromGroup').set_sensitive(True)
         else:
             self.get('miRemoveFromGroup').set_sensitive(False)
@@ -712,9 +801,10 @@ which is incompatible with the current epoptes version.\
     
     ## FIXME / FIXUS: Proofread this (root etc...)
     def execOnClients(self, command, clients=[], reply=None, root=False,
-                        handles=[], warning=''):
+                        handles=[], warning='', params=None):
         '''reply should be a method in which the result will be sent'''
-        
+        if params is None:
+            params = []
         if len(self.cstore) == 0:
             # print 'No clients'
             return False
@@ -724,9 +814,10 @@ which is incompatible with the current epoptes version.\
         if clients == [] and handles != []:
             for handle in handles:
                 cmd = self.daemon.command(handle, unicode(command))
-                cmd.addErrback(self.printErrors)
                 if reply:
-                    cmd.addCallback(lambda re, h=handle: reply(h, re))
+                    cmd.addCallback(lambda re, h=handle, p=params: reply(h, re, *p))
+                    cmd.addErrback(lambda err: self.printErrors("when executing command %s on client %s: %s" %(command,handle, err)))
+
         for client in clients:
             if (root == "auto" or not root) and client[C_SESSION_HANDLE] != '':
                 handle = client[C_SESSION_HANDLE]
@@ -735,9 +826,9 @@ which is incompatible with the current epoptes version.\
             else:
                 continue
             cmd = self.daemon.command(handle, unicode(command))
-            cmd.addErrback(self.printErrors)
             if reply:
-                cmd.addCallback(lambda re, h=handle: reply(h, re))
+                cmd.addCallback(lambda re, h=handle, p=params: reply(h, re, *p))
+                cmd.addErrback(lambda err: self.printErrors("when executing command %s on client %s: %s" %(command,handle, err)))
 
     def execOnSelectedClients(self, command, reply=None, root=False, warn=''):
         clients = self.getSelectedClients()
@@ -761,46 +852,7 @@ which is incompatible with the current epoptes version.\
         else:
             return False
 
-    
-    ## FIXME/ DELETEME??
     def printErrors(self, error):
-        print 'ErrorCallback:', error
+        print '  **Twisted error:', error
         return
 
-    def openTerminal(self, as_root):
-        clients = self.getSelectedClients()
-        
-        # If there is no client selected, send the command to all
-        if len(clients) == 0:
-            clients = self.cstore
-
-        if as_root:
-            screen_params = "bash -l"
-        else:
-            screen_params = "-l"
-
-        for client in clients:
-            inst = client[C_INSTANCE]
-            if inst.type == 'offline':
-                continue
-            elif inst.type == 'thin' and not as_root:
-                server = "127.0.0.1"
-            else:
-                server = "server"
-
-            port = self.findUnusedPort()
-
-            subprocess.Popen(['xterm', '-e', 'socat',
-                'tcp-listen:%d,keepalive=1' % port, 'stdio,raw,echo=0'])
-            self.execOnClients(("""./execute sh -c "cd; sleep 1; """ + 
-                """TERM=xterm exec socat SYSTEM:'exec screen %s',pty,""" + 
-                """stderr tcp:$SERVER:%d" """) % (screen_params, port),
-                [client], root=as_root)
-
-    def execInTerminal(self, widget, command):
-        name = widget.get_child().get_text()
-        subprocess.Popen([ 'x-terminal-emulator', '-e', 'sh', '-c', command
-            + ' && read -p "Script \'%s\' finished succesfully. Press [Enter] to close this window." dummy' % name
-            + ' || read -p "Script \'%s\' finished with errors. Press [Enter] to close this window." dummy' % name]
-            )
-
